summaryrefslogtreecommitdiff
path: root/contrib/cirrus/container_test.sh
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/cirrus/container_test.sh')
-rw-r--r--contrib/cirrus/container_test.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/contrib/cirrus/container_test.sh b/contrib/cirrus/container_test.sh
index 8a4ed9492..b56a12232 100644
--- a/contrib/cirrus/container_test.sh
+++ b/contrib/cirrus/container_test.sh
@@ -18,7 +18,7 @@ if [ "${ID}" != "fedora" ] || [ "${CONTAINER_RUNTIME}" != "" ]; then
INTEGRATION_TEST_ENVS="SKIP_USERNS=1"
fi
-echo "$(date --rfc-3339=seconds) $(basename $0) started with '$*' and TEST_REMOTE_CLIENT='${TEST_REMOTE_CLIENT}'"
+echo "$(date --rfc-3339=seconds) $(basename $0) started with '$*' and RCLI='${RCLI}'"
pwd
@@ -57,9 +57,9 @@ while getopts "bituv" opt; do
esac
done
# The TEST_REMOTE_CLIENT environment variable decides whether
# to test varlinke
-if [[ "$TEST_REMOTE_CLIENT" == "true" ]]; then
+if [[ "$RCLI" == "true" ]]; then
remote=1
fi
@@ -57,9 +57,9 @@ while getopts "bituv" opt; do
esac
done
-# The TEST_REMOTE_CLIENT environment variable decides whether
+# The RCLI environment variable decides whether
# to test varlinke